@@ -7,9 +7,10 @@ class ConnectionInfo:
     数据库连接信息对象
     """
 
-    def __init__(self, dialect: str, host: str, port: int, user: str = None, password: str = None,
+    def __init__(self, dialect: str, dsn: str = None, host: str = None, port: int = None, user: str = None,
+                 password: str = None,
                  db_name: Any = None, name: str = None, params: dict = None, min_size: int = 3, max_size: int = 10,
-                 enable: bool = True, async_enable: bool = False):
+                 enable: bool = True, async_enable: bool = False, connect_keepalive: bool = True):
         # 数据库dialect类型
         self.dialect = dialect
         # 连接池名称
@@ -17,6 +18,8 @@ class ConnectionInfo:
             self.name = name
         else:
             self.name = dialect
+        # dsn
+        self.dsn = dsn
         # 主机地址
         self.host = host
         # 端口号
@@ -37,3 +40,5 @@ class ConnectionInfo:
         self.enable = enable
         # 是否启用异步
         self.async_enable = async_enable
+        # 是否启用session
+        self.connect_keepalive = connect_keepalive
